package App::lcpan::Manual;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-05-04'; # DATE
our $DIST = 'App-lcpan-Manual'; # DIST
our $VERSION = '1.052.000'; # VERSION

1;
# ABSTRACT: Manual for App::lcpan

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::Manual - Manual for App::lcpan

=head1 VERSION

version 1.052.000

=head1 DESCRIPTION

This distribution contains the following documentation pages:

=over

=item * L<App::lcpan::Manual::Cookbook>

=item * L<App::lcpan::Manual::FAQ>

=item * L<App::lcpan::Manual::Internals>

=item * L<App::lcpan::Manual::Tutorial>

=item * L<App::lcpan::Manual::Tutorial::100_WhatIsLcpan>

=item * L<App::lcpan::Manual::Tutorial::800_WritingASubcommand>

=back

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
